#line 2 "ascend_scanner.c"

#line 4 "ascend_scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer ascend_create_buffer
#define yy_delete_buffer ascend_delete_buffer
#define yy_flex_debug ascend_flex_debug
#define yy_init_buffer ascend_init_buffer
#define yy_flush_buffer ascend_flush_buffer
#define yy_load_buffer_state ascend_load_buffer_state
#define yy_switch_to_buffer ascend_switch_to_buffer
#define yyin ascendin
#define yyleng ascendleng
#define yylex ascendlex
#define yylineno ascendlineno
#define yyout ascendout
#define yyrestart ascendrestart
#define yytext ascendtext
#define yywrap ascendwrap
#define yyalloc ascendalloc
#define yyrealloc ascendrealloc
#define yyfree ascendfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE ascendrestart(ascendin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int ascendleng;

extern FILE *ascendin, *ascendout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up ascendtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up ascendtext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via ascendrestart()), so that the user can continue scanning by
	 * just pointing ascendin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when ascendtext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int ascendleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow ascendwrap()'s to do buffer switches
 * instead of setting up a fresh ascendin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void ascendrestart (FILE *input_file  );
void ascend_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE ascend_create_buffer (FILE *file,int size  );
void ascend_delete_buffer (YY_BUFFER_STATE b  );
void ascend_flush_buffer (YY_BUFFER_STATE b  );
void ascendpush_buffer_state (YY_BUFFER_STATE new_buffer  );
void ascendpop_buffer_state (void );

static void ascendensure_buffer_stack (void );
static void ascend_load_buffer_state (void );
static void ascend_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER ascend_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE ascend_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE ascend_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE ascend_scan_bytes (yyconst char *bytes,int len  );

void *ascendalloc (yy_size_t  );
void *ascendrealloc (void *,yy_size_t  );
void ascendfree (void *  );

#define yy_new_buffer ascend_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        ascendensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ascend_create_buffer(ascendin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        ascendensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            ascend_create_buffer(ascendin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *ascendin = (FILE *) 0, *ascendout = (FILE *) 0;

typedef int yy_state_type;

extern int ascendlineno;

int ascendlineno = 1;

extern char *ascendtext;
#define yytext_ptr ascendtext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up ascendtext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	ascendleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 38
#define YY_END_OF_BUFFER 39
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[342] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   11,   11,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,   20,   20,    0,    0,    0,    0,   39,   37,
       35,   35,   35,   35,   37,   37,   37,   37,   35,   37,
       37,   37,   37,   12,   12,   12,   14,   14,   15,   15,
       16,   16,   37,   37,   35,   35,   35,   35,   35,   10,
       10,   10,   10,   10,   10,   11,   11,   35,   35,   35,
       35,   35,   35,   37,   35,   35,   35,   35,   35,   35,

       35,   30,   30,   30,   30,   30,   30,   32,   32,   32,
       37,   20,   20,   20,   20,   20,   20,    9,    9,    9,
        9,    9,    9,    8,    8,    8,    8,    8,    8,   35,
        0,   35,    0,    0,    0,    0,    0,    0,   36,    0,
        0,    0,    0,   34,   12,    0,   14,   15,   16,    0,
        0,   18,   18,   10,   10,   10,   10,   10,   10,   10,
       11,   22,   23,   35,    0,   26,   27,   28,   35,   30,
       30,   30,   30,   30,   30,   30,   32,    0,   20,   20,
       20,   20,   20,   20,   20,    9,    9,    9,    9,    9,
        9,    9,    8,    8,    8,    8,    8,    8,    8,    0,

        0,    0,    0,    0,    0,    0,    0,    0,    0,   13,
        0,    0,   10,   10,   10,   35,    0,    0,   30,   30,
       30,    0,   20,   20,   20,    9,    9,    9,    8,    8,
        8,    0,    0,    0,    0,    5,    0,    4,    0,   36,
        0,    0,   19,   10,   10,   10,   24,    0,    0,   30,
       30,   30,    0,   20,   20,   20,    9,    9,    9,    8,
        8,    8,   21,    1,    0,    0,    0,    0,    5,    0,
        4,    0,    0,   10,   25,    0,   30,    0,   20,    9,
        8,    7,    0,    0,    0,    0,    0,    0,   33,    6,
        0,    0,    0,   17,    0,    3,    0,    0,    0,    2,

        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,   31,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   29,
        0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    5,    1,    1,    1,    1,    1,    6,
        1,    1,    1,    1,    7,    1,    8,    9,   10,   10,
       10,   10,   10,   10,   10,   10,   10,   11,    1,    1,
        1,    1,    1,    1,   12,   13,   14,   15,   16,   13,
       17,   18,   19,   17,   17,   20,   21,   22,   23,   24,
       17,   25,   26,   27,   28,   29,   30,   31,   17,   17,
       32,    1,   33,    1,   34,    1,   35,   13,   36,   13,

       37,   13,   17,   38,   39,   17,   40,   41,   42,   43,
       44,   45,   17,   17,   46,   47,   48,   17,   17,   49,
       50,   17,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[51] =
    {   0,
        1,    2,    3,    4,    1,    5,    1,    6,    7,    7,
        8,    7,    7,    7,    7,    7,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
       10,    1,    1,    9,    7,    7,    7,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,   10,    9
    } ;

static yyconst flex_int16_t yy_base[363] =
    {   0,
        0,   39,   82,    0,  121,  144,  167,  190,  213,  236,
        2,   41,  264,    0,  293,  332,  371,  394,  417,  440,
      463,  486,  509,  532,   84,   97,  555,  578,  601,  624,
      647,  670,  118,  141,  700,  746,  163,  165,  789,    0,
      186,  188,  824,  869,  911,  953,  995, 1037,  591, 1433,
        9,   10,  555,  562,    4,  568,  568,  561,  534,  542,
        3,    0,   10,   12,   19,  530,   36,   12,   68,   70,
       72,   79,    0,  572,   53,   74,  540,  547,  526,    0,
     1076,   76,  177,  536,   71,   94,  129,  131,  152,  154,
      175,  221,  230,  530,  232,  238,  240,  244,  246,  248,

      533,    0, 1117,  176,  234,  531,   81,  178,  233,  519,
      236,    0, 1158,  238,  241,  525,  197,    0, 1199,  261,
      264,  524,  224,    0, 1240,  263,  267,  523,  250,    0,
        0,  511,  537,  530,  534,  538,  517,  531, 1433,  502,
      500,  503,  539,  308,    0,    0,    0,    0,    0,    0,
      539,    0,  491,    0,  266,  289,    0,  490,  490,  493,
        0,    0,    0,  312,  490,    0,    0,    0,  483,    0,
      300,  301,    0,  483,  483,  486,    0,  482,    0,  302,
      303,    0,  479,  477,  480,    0,  304,  305,    0,  474,
      474,  473,    0,  308,  324,    0,  467,  467,  470,  472,

      492,  500,  499,  476,  489,  476,  463,  459,  461, 1433,
        0,  493,  455,  451,  453,  314,  452,  440,  448,  444,
      446,  445,  444,  440,  440,  439,  435,  437,  432,  428,
      430,  455,  438,  337,  119,    0,  443,  351,  414,  449,
      448,    0, 1433,  411,  446,  443,    0,  442,  415,  404,
      435,  434,  440,  396,  429,  428,  391,  426,  425,  388,
      423,  420, 1433, 1433,  408,  401,  414,  402,  352,  410,
      354,  375,  387,  371, 1433,  412,  369,    0,  368,  367,
      366, 1433,  384,  379,  388,  386,  394,  365,    0, 1433,
      392,  371,  374, 1433,  351, 1433,  386,  364,  387, 1433,

      363,  354,  354,  338,  369,  336,  363,  341,  351,  333,
      350,  327,  360,  323,  362,  360,  291,  279,  287,  275,
      245,  287,  241,  225,  222,  193, 1433,  160,  157,  149,
      169,  134,  132,  117,  106,  131,   54,   49,   58, 1433,
     1433, 1289, 1299, 1309, 1319, 1329, 1339, 1343, 1350, 1354,
       53, 1358, 1368, 1378, 1382, 1392, 1402, 1412,   32,   16,
        1, 1422
    } ;

static yyconst flex_int16_t yy_def[363] =
    {   0,
      342,  342,  342,    3,    2,    2,    2,    2,    2,    2,
        2,    2,    2,   13,  343,  343,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,  344,  344,    2,    2,    3,   39,
        2,    2,  345,  345,  346,  346,  347,  347,  341,  341,
      348,  348,   52,   52,  341,  341,  341,  341,   52,  341,
      341,  349,  341,  350,  350,   65,   52,   52,   67,   52,
       67,   52,  351,  341,  352,  352,   76,   76,   76,  353,
      353,   81,   81,  353,  353,   67,   52,   67,   52,   67,
       52,   67,   52,  341,   67,   52,   67,   52,   67,   52,

       52,  354,  354,  103,  103,  354,  354,  355,  355,  109,
      341,  356,  356,  113,  113,  356,  356,  357,  357,  119,
      119,  357,  357,  358,  358,  125,  125,  358,  358,   52,
       52,   52,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  349,  341,   65,   65,   68,   70,   72,  359,
      341,   52,   52,  353,   81,   81,  353,  353,  353,  353,
       87,   52,   52,   52,  341,   52,   52,   52,   52,  354,
      103,  103,  354,  354,  354,  354,  109,  341,  356,  113,
      113,  356,  356,  356,  356,  357,  119,  119,  357,  357,
      357,  357,  358,  125,  125,  358,  358,  358,  358,  341,

      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      360,  341,  353,  353,  353,   52,  341,  341,  354,  354,
      354,  341,  356,  356,  356,  357,  357,  357,  358,  358,
      358,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  361,  341,  353,  353,  353,   52,  341,  341,  354,
      354,  354,  341,  356,  356,  356,  357,  357,  357,  358,
      358,  358,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  353,  341,  341,  354,  362,  356,  357,
      358,  341,  341,  341,  341,  341,  341,  341,  362,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,

      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
        0,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341
    } ;

static yyconst flex_int16_t yy_nxt[1484] =
    {   0,
      341,  341,  341,  341,  341,  341,  269,  273,   51,   52,
      269,   52,   52,   52,   53,   54,   52,   52,  144,  144,
      147,  147,  242,   55,   56,   50,   50,  134,  135,   57,
       58,   50,   50,   73,   59,   52,   52,  141,  211,  131,
      341,  142,  146,   60,  147,  147,   61,   51,   52,  341,
       52,   52,   52,   53,   54,   52,   52,  131,  341,  150,
      146,  340,   55,   56,   50,   50,  131,  341,   57,   58,
       50,   50,   73,   59,   52,   52,  148,  148,  148,  148,
      149,  149,   60,  131,  131,   61,   62,  149,  149,   63,
       64,   65,  339,   65,   65,   65,   65,   65,   52,   52,

      338,  131,  161,  161,  341,  159,  154,   50,   50,  160,
       94,   52,   52,   50,   50,  175,   66,   65,   65,  176,
       50,   50,  341,   94,  154,   60,   50,   50,   61,   67,
       68,  101,   52,   52,  337,   52,   52,  161,  161,  162,
      162,   50,   50,  267,   50,   50,  336,   50,   50,  268,
       50,   50,   67,   68,  101,   52,   52,  335,   52,   52,
      162,  162,  163,  163,   50,   50,  334,   50,   50,  333,
       50,   50,  332,   50,   50,   69,   70,   52,   52,   52,
       52,   52,   52,  163,  163,  331,   50,   50,   50,   50,
       50,   50,  330,   50,  329,   50,   50,   50,   69,   70,

       52,   52,   52,   52,   52,   52,  170,  154,  131,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   50,
       50,   71,   72,  157,  170,  154,  131,   52,   52,  164,
      164,  184,  111,  328,  111,  185,   50,   50,  164,  164,
      166,  166,   50,   50,   71,   72,  166,  166,  167,  167,
       52,   52,  167,  167,  168,  168,  168,  168,  191,   50,
       50,  327,  192,  341,  170,   50,   50,   74,  179,  326,
      141,  179,   75,   76,  142,   76,   76,   76,   77,   78,
      173,  341,  170,  325,  198,  178,  179,  182,  199,  179,
      324,  186,  323,  193,  186,   73,  154,  193,   79,   76,

       76,   81,   82,   50,   82,   82,   82,   82,   82,  186,
      189,  193,  186,  196,  154,  193,  144,  144,  322,  154,
      216,  216,  247,  247,  321,  320,  319,   83,   82,   82,
      170,  170,  179,  179,  186,  186,   84,  154,  193,   85,
       81,   82,   50,   82,   82,   82,   82,   82,  170,  170,
      179,  179,  186,  186,  193,  265,  193,  271,  269,  266,
      271,  271,  269,  318,  271,  317,   83,   82,   82,  316,
      315,  314,  193,  313,  312,   84,  311,  310,   85,   86,
       87,  309,  308,  307,  306,   52,   52,  305,  304,  303,
      302,  301,  300,  299,   50,   50,  298,  297,  296,  295,

       50,   50,   86,   87,  294,  293,  292,  291,   52,   52,
      290,  196,  189,  182,  173,  288,  157,   50,   50,  287,
      139,  286,  285,   50,   50,   88,   89,  284,  283,  282,
      196,   52,   52,  196,  281,  139,  139,  280,  182,  182,
       50,   50,  279,  278,  173,  173,   50,   50,   88,   89,
      277,  276,  275,  139,   52,   52,  139,  274,  139,  139,
      272,  270,  264,   50,   50,  263,  262,  261,  260,   50,
       50,   90,   91,  259,  258,  257,  256,   52,   52,  255,
      254,  253,  252,  251,  250,  249,   50,   50,  248,  246,
      245,  244,   50,   50,   90,   91,  243,  241,  240,  239,

       52,   52,  238,  237,  236,  235,  234,  233,  232,   50,
       50,  231,  230,  229,  228,   50,   50,   92,   93,  227,
      226,  225,  224,   52,   52,  223,  222,  221,  220,  219,
      218,  217,   50,   50,  215,  214,  213,  200,   50,   50,
       92,   93,  212,  210,  209,  208,   52,   52,  207,  206,
      205,  204,  203,  202,  201,   50,   50,  200,  197,  190,
      183,   50,   50,   95,   96,  139,  174,  169,  165,   52,
       52,  158,  139,  133,  153,  151,  139,  140,   50,   50,
      139,  138,  137,  136,   50,   50,   95,   96,  133,  132,
      341,  341,   52,   52,  341,  341,  341,  341,  341,  341,

      341,   50,   50,  341,  341,  341,  341,   50,   50,   97,
       98,  341,  341,  341,  341,   52,   52,  341,  341,  341,
      341,  341,  341,  341,   50,   50,  341,  341,  341,  341,
       50,   50,   97,   98,  341,  341,  341,  341,   52,   52,
      341,  341,  341,  341,  341,  341,  341,   50,   50,  341,
      341,  341,  341,   50,   50,   99,  100,  341,  341,  341,
      341,   52,   52,  341,  341,  341,  341,  341,  341,  341,
       50,   50,  341,  341,  341,  341,   50,   50,   99,  100,
      341,  341,  341,  341,   52,   52,  341,  341,  341,  341,
      341,  341,  341,   50,   50,  341,  341,  341,  341,   50,

       50,   50,   50,   50,  341,  341,  341,  341,  103,  104,
      341,  104,  104,  104,  104,  104,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  105,  104,  104,  341,  341,  341,
      341,  341,  341,  106,  341,  341,  107,   50,   50,   50,
      341,  341,  341,  341,  103,  104,  341,  104,  104,  104,
      104,  104,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      105,  104,  104,  341,  341,  341,  341,  341,  341,  106,
      341,  341,  107,   50,  341,  341,   50,  108,  109,  341,

      109,  109,  109,  109,  109,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  110,  109,  109,   50,  341,  341,  341,
      341,  341,  113,  114,  341,  114,  114,  114,  114,  114,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  115,  114,
      114,  341,  341,  341,  341,  341,  341,  116,  341,  341,
      117,   50,  341,  341,  341,  341,  341,  113,  114,  341,
      114,  114,  114,  114,  114,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,

      341,  341,  341,  115,  114,  114,  341,  341,  341,  341,
      341,  341,  116,  341,  341,  117,   50,  341,   50,  119,
      120,   50,  120,  120,  120,  120,  120,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  121,  120,  120,  341,  341,
      341,  341,  341,  341,  122,  341,  341,  123,   50,  341,
       50,  119,  120,   50,  120,  120,  120,  120,  120,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  121,  120,  120,
      341,  341,  341,  341,  341,  341,  122,  341,  341,  123,

       50,  341,  341,  125,  126,  341,  126,  126,  126,  126,
      126,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  127,
      126,  126,  341,  341,  341,  341,  341,  341,  128,  341,
      341,  129,   50,  341,  341,  125,  126,  341,  126,  126,
      126,  126,  126,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  127,  126,  126,  341,  341,  341,  341,  341,  341,
      128,  341,  341,  129,  155,  155,  341,  155,  155,  155,
      155,  155,  341,  341,  341,  341,  341,  341,  341,  341,

      341,  341,  341,  341,  341,  341,  156,  341,  341,  341,
      155,  155,  155,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  156,  171,  171,  341,  171,  171,
      171,  171,  171,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  172,  341,  341,
      341,  171,  171,  171,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  172,  180,  180,  341,  180,
      180,  180,  180,  180,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  181,  341,
      341,  341,  180,  180,  180,  341,  341,  341,  341,  341,

      341,  341,  341,  341,  341,  341,  181,  187,  187,  341,
      187,  187,  187,  187,  187,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  188,
      341,  341,  341,  187,  187,  187,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  188,  194,  194,
      341,  194,  194,  194,  194,  194,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      195,  341,  341,  341,  194,  194,  194,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  195,   50,
       50,   50,   50,   50,   50,   50,   50,   50,   50,   80,

       80,   80,   80,   80,   80,   80,   80,   80,   80,  102,
      102,  102,  102,  102,  102,  102,  102,  102,  102,  112,
      112,  112,  112,  112,  112,  112,  112,  112,  112,  118,
      118,  118,  118,  118,  118,  118,  118,  118,  118,  124,
      124,  124,  124,  124,  124,  124,  124,  124,  124,  130,
      341,  341,  130,  143,  341,  341,  143,  341,  143,  143,
      145,  341,  341,  145,  152,  341,  341,  152,  154,  154,
      154,  154,  154,  154,  154,  341,  154,  154,  170,  341,
      341,  341,  170,  170,  170,  170,  170,  170,  177,  341,
      341,  177,  179,  179,  341,  179,  179,  179,  179,  179,

      179,  179,  186,  186,  186,  186,  341,  341,  186,  341,
      186,  186,  193,  193,  193,  193,  341,  193,  193,  193,
      193,  193,  289,  341,  341,  341,  289,  289,  289,  289,
      289,  289,   49,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341
    } ;

static yyconst flex_int16_t yy_chk[1484] =
    {   0,
        0,    0,    0,    0,    0,    0,  236,  361,    1,    1,
      236,    1,    1,    1,    1,    1,   11,   11,   63,   63,
       68,   68,  360,    1,    1,   11,   11,   55,   55,    1,
        1,   11,   11,   11,    1,    1,    1,   61,  359,   51,
       52,   61,   64,    1,   67,   67,    1,    2,    2,   65,
        2,    2,    2,    2,    2,   12,   12,   51,   52,  351,
       64,  339,    2,    2,   12,   12,   67,   65,    2,    2,
       12,   12,   12,    2,    2,    2,   69,   69,   70,   70,
       71,   71,    2,   75,   67,    2,    3,   72,   72,    3,
        3,    3,  338,    3,    3,    3,    3,    3,   25,   25,

      337,   75,   86,   86,   76,   85,   82,   25,   25,   85,
       25,   26,   26,   25,   25,  107,    3,    3,    3,  107,
       26,   26,   76,   26,   82,    3,   26,   26,    3,    5,
        5,   33,   33,   33,  336,    5,    5,   87,   87,   88,
       88,   33,   33,  235,    5,    5,  335,   33,   33,  235,
        5,    5,    6,    6,   34,   34,   34,  334,    6,    6,
       89,   89,   90,   90,   34,   34,  333,    6,    6,  332,
       34,   34,  331,    6,    6,    7,    7,   37,   37,   38,
       38,    7,    7,   91,   91,  330,   37,   37,   38,   38,
        7,    7,  329,   37,  328,   38,    7,    7,    8,    8,

       41,   41,   42,   42,    8,    8,  104,   83,  108,   41,
       41,   42,   42,    8,    8,   41,   41,   42,   42,    8,
        8,    9,    9,   83,  104,   83,  108,    9,    9,   92,
       92,  117,   41,  326,   42,  117,    9,    9,   93,   93,
       95,   95,    9,    9,   10,   10,   96,   96,   97,   97,
       10,   10,   98,   98,   99,   99,  100,  100,  123,   10,
       10,  325,  123,  109,  105,   10,   10,   13,  114,  324,
      111,  115,   13,   13,  111,   13,   13,   13,   13,   13,
      105,  109,  105,  323,  129,  111,  114,  115,  129,  115,
      322,  120,  321,  126,  121,   13,  155,  127,   13,   13,

       13,   15,   15,   15,   15,   15,   15,   15,   15,  120,
      121,  126,  121,  127,  155,  127,  144,  144,  320,  156,
      164,  164,  216,  216,  319,  318,  317,   15,   15,   15,
      171,  172,  180,  181,  187,  188,   15,  156,  194,   15,
       16,   16,   16,   16,   16,   16,   16,   16,  171,  172,
      180,  181,  187,  188,  195,  234,  194,  238,  269,  234,
      271,  238,  269,  316,  271,  315,   16,   16,   16,  314,
      313,  312,  195,  311,  310,   16,  309,  308,   16,   17,
       17,  307,  306,  305,  304,   17,   17,  303,  302,  301,
      299,  298,  297,  295,   17,   17,  293,  292,  291,  288,

       17,   17,   18,   18,  287,  286,  285,  284,   18,   18,
      283,  281,  280,  279,  277,  276,  274,   18,   18,  273,
      272,  270,  268,   18,   18,   19,   19,  267,  266,  265,
      262,   19,   19,  261,  260,  259,  258,  257,  256,  255,
       19,   19,  254,  253,  252,  251,   19,   19,   20,   20,
      250,  249,  248,  246,   20,   20,  245,  244,  241,  240,
      239,  237,  233,   20,   20,  232,  231,  230,  229,   20,
       20,   21,   21,  228,  227,  226,  225,   21,   21,  224,
      223,  222,  221,  220,  219,  218,   21,   21,  217,  215,
      214,  213,   21,   21,   22,   22,  212,  209,  208,  207,

       22,   22,  206,  205,  204,  203,  202,  201,  200,   22,
       22,  199,  198,  197,  192,   22,   22,   23,   23,  191,
      190,  185,  184,   23,   23,  183,  178,  176,  175,  174,
      169,  165,   23,   23,  160,  159,  158,  153,   23,   23,
       24,   24,  151,  143,  142,  141,   24,   24,  140,  138,
      137,  136,  135,  134,  133,   24,   24,  132,  128,  122,
      116,   24,   24,   27,   27,  110,  106,  101,   94,   27,
       27,   84,   79,   78,   77,   74,   66,   60,   27,   27,
       59,   58,   57,   56,   27,   27,   28,   28,   54,   53,
       49,    0,   28,   28,    0,    0,    0,    0,    0,    0,

        0,   28,   28,    0,    0,    0,    0,   28,   28,   29,
       29,    0,    0,    0,    0,   29,   29,    0,    0,    0,
        0,    0,    0,    0,   29,   29,    0,    0,    0,    0,
       29,   29,   30,   30,    0,    0,    0,    0,   30,   30,
        0,    0,    0,    0,    0,    0,    0,   30,   30,    0,
        0,    0,    0,   30,   30,   31,   31,    0,    0,    0,
        0,   31,   31,    0,    0,    0,    0,    0,    0,    0,
       31,   31,    0,    0,    0,    0,   31,   31,   32,   32,
        0,    0,    0,    0,   32,   32,    0,    0,    0,    0,
        0,    0,    0,   32,   32,    0,    0,    0,    0,   32,

       32,   35,   35,   35,    0,    0,    0,    0,   35,   35,
        0,   35,   35,   35,   35,   35,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   35,   35,   35,    0,    0,    0,
        0,    0,    0,   35,    0,    0,   35,   36,   36,   36,
        0,    0,    0,    0,   36,   36,    0,   36,   36,   36,
       36,   36,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
       36,   36,   36,    0,    0,    0,    0,    0,    0,   36,
        0,    0,   36,   39,    0,    0,   39,   39,   39,    0,

       39,   39,   39,   39,   39,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   39,   39,   39,   43,    0,    0,    0,
        0,    0,   43,   43,    0,   43,   43,   43,   43,   43,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,   43,   43,
       43,    0,    0,    0,    0,    0,    0,   43,    0,    0,
       43,   44,    0,    0,    0,    0,    0,   44,   44,    0,
       44,   44,   44,   44,   44,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,   44,   44,   44,    0,    0,    0,    0,
        0,    0,   44,    0,    0,   44,   45,    0,   45,   45,
       45,   45,   45,   45,   45,   45,   45,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,   45,   45,   45,    0,    0,
        0,    0,    0,    0,   45,    0,    0,   45,   46,    0,
       46,   46,   46,   46,   46,   46,   46,   46,   46,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   46,   46,   46,
        0,    0,    0,    0,    0,    0,   46,    0,    0,   46,

       47,    0,    0,   47,   47,    0,   47,   47,   47,   47,
       47,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,   47,
       47,   47,    0,    0,    0,    0,    0,    0,   47,    0,
        0,   47,   48,    0,    0,   48,   48,    0,   48,   48,
       48,   48,   48,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,   48,   48,   48,    0,    0,    0,    0,    0,    0,
       48,    0,    0,   48,   81,   81,    0,   81,   81,   81,
       81,   81,    0,    0,    0,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,   81,    0,    0,    0,
       81,   81,   81,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   81,  103,  103,    0,  103,  103,
      103,  103,  103,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  103,    0,    0,
        0,  103,  103,  103,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,  103,  113,  113,    0,  113,
      113,  113,  113,  113,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  113,    0,
        0,    0,  113,  113,  113,    0,    0,    0,    0,    0,

        0,    0,    0,    0,    0,    0,  113,  119,  119,    0,
      119,  119,  119,  119,  119,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,  119,
        0,    0,    0,  119,  119,  119,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,  119,  125,  125,
        0,  125,  125,  125,  125,  125,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
      125,    0,    0,    0,  125,  125,  125,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,  125,  342,
      342,  342,  342,  342,  342,  342,  342,  342,  342,  343,

      343,  343,  343,  343,  343,  343,  343,  343,  343,  344,
      344,  344,  344,  344,  344,  344,  344,  344,  344,  345,
      345,  345,  345,  345,  345,  345,  345,  345,  345,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  347,
      347,  347,  347,  347,  347,  347,  347,  347,  347,  348,
        0,    0,  348,  349,    0,    0,  349,    0,  349,  349,
      350,    0,    0,  350,  352,    0,    0,  352,  353,  353,
      353,  353,  353,  353,  353,    0,  353,  353,  354,    0,
        0,    0,  354,  354,  354,  354,  354,  354,  355,    0,
        0,  355,  356,  356,    0,  356,  356,  356,  356,  356,

      356,  356,  357,  357,  357,  357,    0,    0,  357,    0,
      357,  357,  358,  358,  358,  358,    0,  358,  358,  358,
      358,  358,  362,    0,    0,    0,  362,  362,  362,  362,
      362,  362,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341,  341,  341,  341,  341,  341,  341,  341,
      341,  341,  341
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int ascend_flex_debug;
int ascend_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *ascendtext;
#line 1 "ascend_scanner.l"
/*
 * We don't read from the terminal.
 */
/*
 * Prefix scanner routines with "ascend" rather than "yy", so this scanner
 * can coexist with other scanners.
 */
#line 13 "ascend_scanner.l"
/* ascend_scanner.l
 *
 * $Id: ascend_scanner.l 28744 2009-06-15 18:56:46Z jmayer $
 *
 * Wiretap Library
 * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifdef HAVE_IO_H
#include <io.h> 	/* for isatty() on win32 */
#endif

#include "wtap-int.h"
#include "ascendtext.h"
#include "ascend.h"
#include "ascend-int.h"
#include "file_wrappers.h"
#include "ascend_scanner_lex.h"

FILE_T yy_fh;
extern char *ascend_ra_ptr;
extern char *ascend_ra_last;
#define YY_INPUT(buf,result,max_size) { int c = file_getc(yy_fh);  \
result = (c==EOF) ? YY_NULL : (buf[0] = c, 1); } 

int at_eof;
int mul, scratch;

#define NO_USER "<none>"

#ifndef HAVE_UNISTD_H
#define YY_NO_UNISTD_H
#endif

























#line 1009 "ascend_scanner.c"

#define INITIAL 0
#define sc_gen_task 1
#define sc_gen_time_s 2
#define sc_gen_time_u 3
#define sc_gen_octets 4
#define sc_gen_counter 5
#define sc_gen_byte 6
#define sc_wds_user 7
#define sc_wds_sess 8
#define sc_wdd_date_d 9
#define sc_wdd_date_m 10
#define sc_wdd_date_y 11
#define sc_wdd_time 12
#define sc_wdd_time_h 13
#define sc_wdd_time_m 14
#define sc_wdd_time_s 15
#define sc_wdd_cause 16
#define sc_wdd_callnum 17
#define sc_wdd_chunk 18
#define sc_wdd_chunknum 19
#define sc_wdd_type 20
#define sc_chardisp 21
#define sc_isdn_call 22
#define sc_ether_direction 23

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int ascendlex_destroy (void );

int ascendget_debug (void );

void ascendset_debug (int debug_flag  );

YY_EXTRA_TYPE ascendget_extra (void );

void ascendset_extra (YY_EXTRA_TYPE user_defined  );

FILE *ascendget_in (void );

void ascendset_in  (FILE * in_str  );

FILE *ascendget_out (void );

void ascendset_out  (FILE * out_str  );

int ascendget_leng (void );

char *ascendget_text (void );

int ascendget_lineno (void );

void ascendset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int ascendwrap (void );
#else
extern int ascendwrap (void );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  );
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( ascendtext, ascendleng, 1, ascendout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( ascendin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( ascendin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, ascendin))==0 && ferror(ascendin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(ascendin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int ascendlex (void);

#define YY_DECL int ascendlex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after ascendtext and ascendleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 118 "ascend_scanner.l"


#line 1222 "ascend_scanner.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! ascendin )
			ascendin = stdin;

		if ( ! ascendout )
			ascendout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			ascendensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				ascend_create_buffer(ascendin,YY_BUF_SIZE );
		}

		ascend_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of ascendtext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 342 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 341 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 120 "ascend_scanner.l"
{
  BEGIN(sc_ether_direction);
  ascendlval.d = ASCEND_PFX_ETHER;
  return ETHER_PREFIX;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 126 "ascend_scanner.l"
{
  BEGIN(sc_isdn_call);
  ascendlval.d = ASCEND_PFX_ISDN_X;
  return ISDN_PREFIX;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 132 "ascend_scanner.l"
{
  BEGIN(sc_isdn_call);
  ascendlval.d = ASCEND_PFX_ISDN_R;
  return ISDN_PREFIX;
}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 138 "ascend_scanner.l"
{
  BEGIN(sc_wds_user);
  ascendlval.d = ASCEND_PFX_WDS_X;
  return WDS_PREFIX;
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 144 "ascend_scanner.l"
{
  BEGIN(sc_wds_user);
  ascendlval.d = ASCEND_PFX_WDS_R;
  return WDS_PREFIX;
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 150 "ascend_scanner.l"
{
  BEGIN(sc_wds_user);
  ascendlval.d = ASCEND_PFX_WDS_X;
  return WDS_PREFIX;
}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 156 "ascend_scanner.l"
{
  BEGIN(sc_wds_user);
  ascendlval.d = ASCEND_PFX_WDS_R;
  return WDS_PREFIX;
}
	YY_BREAK
case 8:
/* rule 8 can match eol */
YY_RULE_SETUP
#line 162 "ascend_scanner.l"
{
  BEGIN(sc_gen_task);
  return STRING; 
}
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 167 "ascend_scanner.l"
{
  BEGIN(sc_gen_task);
  return DECNUM;
}
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 172 "ascend_scanner.l"
{
  char *atcopy = g_strdup(ascendtext);
  char colon = input();
  char after = input();
  int retval = STRING;

  unput(after); unput(colon);

  if (after != '(' && after != ' ') {
    BEGIN(sc_wds_sess);
    if (pseudo_header != NULL) {
      g_strlcpy(pseudo_header->user, atcopy, ASCEND_MAX_STR_LEN);
    }
  } else {	/* We have a version 7 file */
    BEGIN(sc_gen_task);
    if (pseudo_header != NULL) {
      g_strlcpy(pseudo_header->user, NO_USER, ASCEND_MAX_STR_LEN);
    }
    ascendlval.d = strtol(ascendtext, NULL, 10);
    retval = DECNUM;
  }
  g_free (atcopy);
  return retval;
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 197 "ascend_scanner.l"
{
  BEGIN(sc_gen_task);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 203 "ascend_scanner.l"
{
  BEGIN(sc_gen_time_s);
  ascendlval.d = strtoul(ascendtext, NULL, 16);
  return HEXNUM;
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 209 "ascend_scanner.l"
{
  return STRING;
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 213 "ascend_scanner.l"
{
  BEGIN(sc_gen_time_u);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 219 "ascend_scanner.l"
{
  char *atcopy = g_strdup(ascendtext);
  BEGIN(sc_gen_octets);
  /* only want the most significant 2 digits. convert to usecs */
  if (strlen(atcopy) > 2)
    atcopy[2] = '\0';
  ascendlval.d = strtol(atcopy, NULL, 10) * 10000;
  g_free(atcopy);
  return DECNUM;
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 230 "ascend_scanner.l"
{
  BEGIN(sc_gen_counter);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 236 "ascend_scanner.l"
{
  BEGIN(sc_gen_byte);
  return COUNTER;
}
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 241 "ascend_scanner.l"
{
  ascendlval.b = (guint8)strtol(ascendtext, NULL, 16);
  return HEXBYTE;
}
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 246 "ascend_scanner.l"
{ 
  BEGIN(sc_chardisp);
}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 250 "ascend_scanner.l"
{ 
  BEGIN(sc_gen_byte);
}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 254 "ascend_scanner.l"
{
  BEGIN(sc_wdd_date_d);
  return WDD_DATE;
}
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 259 "ascend_scanner.l"
{
  BEGIN(sc_wdd_date_m);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 265 "ascend_scanner.l"
{
  BEGIN(sc_wdd_date_y);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 271 "ascend_scanner.l"
{
  BEGIN(sc_wdd_time);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 277 "ascend_scanner.l"
{
  BEGIN(sc_wdd_time_h);
  return KEYWORD;
}
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 282 "ascend_scanner.l"
{
  BEGIN(sc_wdd_time_m);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 288 "ascend_scanner.l"
{
  BEGIN(sc_wdd_time_s);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 294 "ascend_scanner.l"
{
  BEGIN(sc_wdd_cause);
  ascendlval.d = strtol(ascendtext, NULL, 10);
  return DECNUM;
}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 300 "ascend_scanner.l"
{
  BEGIN(sc_wdd_callnum);
  return KEYWORD;
}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 305 "ascend_scanner.l"
{
  BEGIN(sc_wdd_chunk);
  if (pseudo_header != NULL) {
    g_strlcpy(pseudo_header->call_num, ascendtext, ASCEND_MAX_STR_LEN);
  }
  return STRING;
}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 313 "ascend_scanner.l"
{
  BEGIN(sc_wdd_chunknum);
  return WDD_CHUNK;
}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 318 "ascend_scanner.l"
{
  BEGIN(sc_wdd_type);
  ascendlval.d = strtoul(ascendtext, NULL, 16);
  return HEXNUM;
}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 324 "ascend_scanner.l"
{
  BEGIN(sc_gen_task);
  return KEYWORD;
}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 329 "ascend_scanner.l"
{
  return SLASH_SUFFIX;
}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 333 "ascend_scanner.l"
{ return HEXNUM; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 335 "ascend_scanner.l"
{ return KEYWORD; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(sc_gen_task):
case YY_STATE_EOF(sc_gen_time_s):
case YY_STATE_EOF(sc_gen_time_u):
case YY_STATE_EOF(sc_gen_octets):
case YY_STATE_EOF(sc_gen_counter):
case YY_STATE_EOF(sc_gen_byte):
case YY_STATE_EOF(sc_wds_user):
case YY_STATE_EOF(sc_wds_sess):
case YY_STATE_EOF(sc_wdd_date_d):
case YY_STATE_EOF(sc_wdd_date_m):
case YY_STATE_EOF(sc_wdd_date_y):
case YY_STATE_EOF(sc_wdd_time):
case YY_STATE_EOF(sc_wdd_time_h):
case YY_STATE_EOF(sc_wdd_time_m):
case YY_STATE_EOF(sc_wdd_time_s):
case YY_STATE_EOF(sc_wdd_cause):
case YY_STATE_EOF(sc_wdd_callnum):
case YY_STATE_EOF(sc_wdd_chunk):
case YY_STATE_EOF(sc_wdd_chunknum):
case YY_STATE_EOF(sc_wdd_type):
case YY_STATE_EOF(sc_chardisp):
case YY_STATE_EOF(sc_isdn_call):
case YY_STATE_EOF(sc_ether_direction):
#line 337 "ascend_scanner.l"
{ at_eof++; yyterminate(); }
	YY_BREAK
case 37:
/* rule 37 can match eol */
YY_RULE_SETUP
#line 339 "ascend_scanner.l"
;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 341 "ascend_scanner.l"
ECHO;
	YY_BREAK
#line 1667 "ascend_scanner.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed ascendin at a new source and called
			 * ascendlex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = ascendin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( ascendwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * ascendtext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of ascendlex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					ascendrealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			ascendrestart(ascendin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) ascendrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 342 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 342 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 341);

	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp )
{
	register char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up ascendtext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register int number_to_move = (yy_n_chars) + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					ascendrestart(ascendin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( ascendwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve ascendtext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void ascendrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        ascendensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            ascend_create_buffer(ascendin,YY_BUF_SIZE );
	}

	ascend_init_buffer(YY_CURRENT_BUFFER,input_file );
	ascend_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void ascend_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		ascendpop_buffer_state();
	 *		ascendpush_buffer_state(new_buffer);
     */
	ascendensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	ascend_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (ascendwrap()) processing, but the only time this flag
	 * is looked at is after ascendwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void ascend_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	ascendin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE ascend_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) ascendalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ascend_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) ascendalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in ascend_create_buffer()" );

	b->yy_is_our_buffer = 1;

	ascend_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with ascend_create_buffer()
 * 
 */
    void ascend_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		ascendfree((void *) b->yy_ch_buf  );

	ascendfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a ascendrestart() or at EOF.
 */
    static void ascend_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	ascend_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then ascend_init_buffer was _probably_
     * called from ascendrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void ascend_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		ascend_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void ascendpush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	ascendensure_buffer_stack();

	/* This block is copied from ascend_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from ascend_switch_to_buffer. */
	ascend_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void ascendpop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	ascend_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		ascend_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void ascendensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)ascendalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in ascendensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)ascendrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in ascendensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE ascend_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) ascendalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in ascend_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	ascend_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to ascendlex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       ascend_scan_bytes() instead.
 */
YY_BUFFER_STATE ascend_scan_string (yyconst char * yystr )
{
    
	return ascend_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to ascendlex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE ascend_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) ascendalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in ascend_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = ascend_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in ascend_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up ascendtext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		ascendtext[ascendleng] = (yy_hold_char); \
		(yy_c_buf_p) = ascendtext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		ascendleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int ascendget_lineno  (void)
{
        
    return ascendlineno;
}

/** Get the input stream.
 * 
 */
FILE *ascendget_in  (void)
{
        return ascendin;
}

/** Get the output stream.
 * 
 */
FILE *ascendget_out  (void)
{
        return ascendout;
}

/** Get the length of the current token.
 * 
 */
int ascendget_leng  (void)
{
        return ascendleng;
}

/** Get the current token.
 * 
 */

char *ascendget_text  (void)
{
        return ascendtext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void ascendset_lineno (int  line_number )
{
    
    ascendlineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see ascend_switch_to_buffer
 */
void ascendset_in (FILE *  in_str )
{
        ascendin = in_str ;
}

void ascendset_out (FILE *  out_str )
{
        ascendout = out_str ;
}

int ascendget_debug  (void)
{
        return ascend_flex_debug;
}

void ascendset_debug (int  bdebug )
{
        ascend_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from ascendlex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    ascendin = stdin;
    ascendout = stdout;
#else
    ascendin = (FILE *) 0;
    ascendout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * ascendlex_init()
     */
    return 0;
}

/* ascendlex_destroy is for both reentrant and non-reentrant scanners. */
int ascendlex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		ascend_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		ascendpop_buffer_state();
	}

	/* Destroy the stack itself. */
	ascendfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * ascendlex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *ascendalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *ascendrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void ascendfree (void * ptr )
{
	free( (char *) ptr );	/* see ascendrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 341 "ascend_scanner.l"



void ascend_init_lexer(FILE_T fh)
{
  ascendrestart(0);
  yy_fh = fh;
  BEGIN(INITIAL);
}

/*
 * We want to stop processing when we get to the end of the input.
 * (%option noyywrap is not used because if used then 
 * some flex versions (eg: 2.5.35) generate code which causes
 * warnings by the Windows VC compiler).
 */

int ascendwrap(void) {
    return 1;
}

